==> AxolotlClient-3.1.6%2B1.8.9-sources.jar: io/github/axolotlclient/bridge/mixin/entity/effect/StatusEffectInstanceMixin.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.bridge.mixin.entity.effect;

import io.github.axolotlclient.bridge.entity.effect.AxoStatusEffect;
import io.github.axolotlclient.bridge.entity.effect.AxoStatusEffectInstance;
import io.github.axolotlclient.bridge.util.AxoText;
import net.minecraft.unmapped.C_0658987;
import net.minecraft.unmapped.C_3488550;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(C_0658987.class)
public abstract class StatusEffectInstanceMixin implements AxoStatusEffectInstance {
	@Shadow
	public abstract int getId();

	@Shadow
	private int amplifier;

	@Override
	public AxoStatusEffect br$getType() {
		return C_3488550.f_4819165[getId()];
	}

	@Override
	public int br$getAmplifier() {
		return amplifier;
	}

	@Override
	public AxoText br$formatDuration() {
		return AxoText.literal(C_3488550.m_6897358((C_0658987) (Object) this));
	}
}

==> AxolotlClient-3.1.7%2B1.21.11-sources.jar: io/github/axolotlclient/bridge/mixin/entity/effect/StatusEffectInstanceMixin.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.bridge.mixin.entity.effect;

import io.github.axolotlclient.bridge.entity.effect.AxoStatusEffect;
import io.github.axolotlclient.bridge.entity.effect.AxoStatusEffectInstance;
import io.github.axolotlclient.bridge.util.AxoText;
import net.minecraft.class_1291;
import net.minecraft.class_1292;
import net.minecraft.class_1293;
import net.minecraft.class_310;
import net.minecraft.class_6880;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;

@Mixin(class_1293.class)
public abstract class StatusEffectInstanceMixin implements AxoStatusEffectInstance {
	@Shadow
	@Final
	private class_6880<class_1291> effect;

	@Shadow
	private int amplifier;

	@Override
	public AxoStatusEffect br$getType() {
		return effect.comp_349();
	}

	@Override
	public int br$getAmplifier() {
		return amplifier;
	}

	@Override
	public AxoText br$formatDuration() {
		final var client = class_310.method_1551();
		final var tickRate = client.field_1687 != null ? client.field_1687.method_54719().method_54748() : 1;
		return class_1292.method_5577((class_1293) (Object) this, 1, tickRate);
	}
}
